summaryrefslogtreecommitdiffstats
path: root/kwin/lib
diff options
context:
space:
mode:
Diffstat (limited to 'kwin/lib')
-rw-r--r--kwin/lib/Makefile.am4
-rw-r--r--kwin/lib/kdecoration.h2
-rw-r--r--kwin/lib/kdecoration_plugins_p.cpp18
3 files changed, 12 insertions, 12 deletions
diff --git a/kwin/lib/Makefile.am b/kwin/lib/Makefile.am
index 1ded5c5d8..af19b7df3 100644
--- a/kwin/lib/Makefile.am
+++ b/kwin/lib/Makefile.am
@@ -1,4 +1,4 @@
-# FRAME libkwin???
+# FRAME libtwin???
lib_LTLIBRARIES = libtdecorations.la
libtdecorations_la_SOURCES = kdecoration.cpp kdecoration_p.cpp kdecoration_plugins_p.cpp \
@@ -16,5 +16,5 @@ METASOURCES = AUTO
include ../../admin/Doxyfile.am
messages: rc.cpp
- $(XGETTEXT) `find . -name \*.cpp` -o $(podir)/kwin_lib.pot
+ $(XGETTEXT) `find . -name \*.cpp` -o $(podir)/twin_lib.pot
-rm rc.cpp
diff --git a/kwin/lib/kdecoration.h b/kwin/lib/kdecoration.h
index 37dc3f69a..ae3c58e28 100644
--- a/kwin/lib/kdecoration.h
+++ b/kwin/lib/kdecoration.h
@@ -582,7 +582,7 @@ class KWIN_EXPORT KDecoration
// mustn't do any repaints, resizes or anything like that
virtual void borders( int& left, int& right, int& top, int& bottom ) const = 0;
/**
- * This method is called by kwin when the style should resize the decoration window.
+ * This method is called by twin when the style should resize the decoration window.
* The usual implementation is to resize the main widget of the decoration to the
* given size.
*
diff --git a/kwin/lib/kdecoration_plugins_p.cpp b/kwin/lib/kdecoration_plugins_p.cpp
index 0490e4755..a7b12ab85 100644
--- a/kwin/lib/kdecoration_plugins_p.cpp
+++ b/kwin/lib/kdecoration_plugins_p.cpp
@@ -42,7 +42,7 @@ KDecorationPlugins::KDecorationPlugins( KConfig* cfg )
fact( NULL ),
old_library( NULL ),
old_fact( NULL ),
- pluginStr( "kwin3_undefined " ),
+ pluginStr( "twin3_undefined " ),
config( cfg )
{
}
@@ -98,9 +98,9 @@ bool KDecorationPlugins::loadPlugin( TQString nameStr )
KConfigGroupSaver saver( config, "Style" );
nameStr = config->readEntry("PluginLib", defaultPlugin );
}
- // make sure people can switch between HEAD and kwin_iii branch
- if( nameStr.startsWith( "kwin_" ))
- nameStr = "kwin3_" + nameStr.mid( 5 );
+ // make sure people can switch between HEAD and twin_iii branch
+ if( nameStr.startsWith( "twin_" ))
+ nameStr = "twin3_" + nameStr.mid( 5 );
KLibrary *oldLibrary = library;
KDecorationFactory* oldFactory = fact;
@@ -114,7 +114,7 @@ bool KDecorationPlugins::loadPlugin( TQString nameStr )
path = KLibLoader::findLibrary(TQFile::encodeName(nameStr));
}
// If no library was found, exit kwin with an error message
if (path.isEmpty())
{
error( i18n("No window decoration plugin library was found." ));
@@ -167,14 +167,14 @@ bool KDecorationPlugins::loadPlugin( TQString nameStr )
// For clients in kdeartwork
TQString catalogue = nameStr;
- catalogue.replace( "kwin3_", "kwin_" );
+ catalogue.replace( "twin3_", "twin_" );
KGlobal::locale()->insertCatalogue( catalogue );
// For KCommonDecoration based clients
- KGlobal::locale()->insertCatalogue( "kwin_lib" );
+ KGlobal::locale()->insertCatalogue( "twin_lib" );
// For clients in kdebase
- KGlobal::locale()->insertCatalogue( "kwin_clients" );
+ KGlobal::locale()->insertCatalogue( "twin_clients" );
// For clients in kdeartwork
- KGlobal::locale()->insertCatalogue( "kwin_art_clients" );
+ KGlobal::locale()->insertCatalogue( "twin_art_clients" );
old_library = oldLibrary; // save for delayed destroying
old_fact = oldFactory;
@@ -114,7 +114,7 @@ bool KDecorationPlugins::loadPlugin( TQString nameStr )
path = KLibLoader::findLibrary(TQFile::encodeName(nameStr));
}
- // If no library was found, exit kwin with an error message
+ // If no library was found, exit twin with an error message
if (path.isEmpty())
{